==> dpu-1.0.2-sources.jar: com/feintha/dpu/mixin/ItemRendererMixin.java <==
package com.feintha.dpu.mixin;

import com.feintha.dpu.alib;
import net.minecraft.class_1087;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_329;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_811;
import net.minecraft.class_918;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
@Mixin(class_918.class)
public abstract class ItemRendererMixin {
    public void runUseAction(class_1799 stack) {
    }

    @Inject(at=@At("HEAD"), method="renderItem(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/item/ItemStack;Lnet/minecraft/client/render/model/json/ModelTransformationMode;ZLnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;Lnet/minecraft/world/World;III)V")
    public void renderItemWithSeed(class_1309 entity, class_1799 stack, class_811 renderMode, boolean leftHanded, class_4587 matrices, class_4597 vertexConsumers, class_1937 world, int light, int overlay, int seed, CallbackInfo ci) {
        alib.setMixinField(stack, "transformationMode", renderMode);
    }
    @Inject(at=@At("HEAD"), method="renderItem(Lnet/minecraft/item/ItemStack;Lnet/minecraft/client/render/model/json/ModelTransformationMode;ZLnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;IILnet/minecraft/client/render/model/BakedModel;)V")
    public void renderItem(class_1799 stack, class_811 renderMode, boolean leftHanded, class_4587 matrices, class_4597 vertexConsumers, int light, int overlay, class_1087 model, CallbackInfo ci) {
        alib.setMixinField(stack, "transformationMode", renderMode);
    }
    @Mixin(class_329.class)
    public static class InGameHudMixin{
        @Inject(method="renderHotbarItem", at=@At("HEAD"))
        void injectRenderHotbarItem(class_4587 matrixStack, int i, int j, float f, class_1657 playerEntity, class_1799 itemStack, int k, CallbackInfo ci){
            alib.setMixinField(itemStack, "isBeingRenderedInHotbar", true);
        }
        @Inject(method="renderHotbarItem", at=@At("RETURN"))
        void injectRenderHotbarItemEnd(class_4587 matrixStack, int i, int j, float f, class_1657 playerEntity, class_1799 itemStack, int k, CallbackInfo ci){
            alib.setMixinField(itemStack, "isBeingRenderedInHotbar", false);
        }
    }

}

==> dpu-1.0.6-sources.jar: com/feintha/dpu/mixin/ItemRendererMixin.java <==
package com.feintha.dpu.mixin;

import com.feintha.dpu.DPU;
//import com.feintha.dpu.DPUBlockHolderClass;
import com.feintha.dpu.alib;
import com.mojang.blaze3d.systems.RenderSystem;
import net.fabricmc.fabric.api.client.rendering.v1.EntityRendererRegistry;
import net.minecraft.class_1087;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_329;
import net.minecraft.class_332;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_763;
import net.minecraft.class_811;
import net.minecraft.class_918;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

@Mixin(class_918.class)
public abstract class ItemRendererMixin {
    @Shadow @Final private class_763 models;

    public void runUseAction(class_1799 stack) {
    }
    @Inject(at=@At("HEAD"), method="renderItem(Lnet/minecraft/entity/LivingEntity;Lnet/minecraft/item/ItemStack;Lnet/minecraft/client/render/model/json/ModelTransformationMode;ZLnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;Lnet/minecraft/world/World;III)V")
    public void renderItemWithSeed(class_1309 entity, class_1799 stack, class_811 renderMode, boolean leftHanded, class_4587 matrices, class_4597 vertexConsumers, class_1937 world, int light, int overlay, int seed, CallbackInfo ci) {
        alib.setMixinField(stack, "transformationMode", renderMode);
    }
    @Inject(at=@At("HEAD"), method="renderItem(Lnet/minecraft/item/ItemStack;Lnet/minecraft/client/render/model/json/ModelTransformationMode;ZLnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;IILnet/minecraft/client/render/model/BakedModel;)V")
    public void renderItem(class_1799 stack, class_811 renderMode, boolean leftHanded, class_4587 matrices, class_4597 vertexConsumers, int light, int overlay, class_1087 model, CallbackInfo ci) {
        alib.setMixinField(stack, "transformationMode", renderMode);
//        if (stack.getItem() instanceof BlockItem bI){
//            if (bI.getBlock() instanceof DPUBlockHolderClass dBH) {
//
//            }
//        }
    }
    @Mixin(class_329.class)
    public static class InGameHudMixin{
        @Inject(method="renderHotbarItem", at=@At("HEAD"))
        void injectRenderHotbarItem(class_332 context, int x, int y, float f, class_1657 player, class_1799 stack, int seed, CallbackInfo ci){
            alib.setMixinField(stack, "isBeingRenderedInHotbar", true);
        }
        @Inject(method="renderHotbarItem", at=@At("RETURN"))
        void injectRenderHotbarItemEnd(class_332 context, int x, int y, float f, class_1657 player, class_1799 stack, int seed, CallbackInfo ci){
            alib.setMixinField(stack, "isBeingRenderedInHotbar", false);
        }
    }

}
